import * as THREE from 'three';

declare class Panel {
    canvas: HTMLCanvasElement;
    context: CanvasRenderingContext2D | null;
    name: string;
    fg: string;
    bg: string;
    PR: number;
    WIDTH: number;
    HEIGHT: number;
    TEXT_X: number;
    TEXT_Y: number;
    GRAPH_X: number;
    GRAPH_Y: number;
    GRAPH_WIDTH: number;
    GRAPH_HEIGHT: number;
    constructor(name: string, fg: string, bg: string);
    update(value: number, valueGraph: number, maxValue: number, maxGraph: number, decimals?: number): void;
}

interface AverageArray {
    logs: number[];
    graph: number[];
}
declare class Stats {
    totalCpuDuration: number;
    totalGpuDuration: number;
    totalFps: number;
    mode: number;
    dom: HTMLDivElement;
    minimal: boolean;
    horizontal: boolean;
    beginTime: number;
    prevTime: number;
    prevCpuTime: number;
    frames: number;
    averageCpu: AverageArray;
    averageGpu: AverageArray;
    queryCreated: boolean;
    isRunningCPUProfiling: boolean;
    fpsPanel: Panel;
    static Panel: typeof Panel;
    msPanel: Panel;
    gpuPanel: Panel | null;
    samplesLog: number;
    samplesGraph: number;
    logsPerSecond: number;
    activeQuery: WebGLQuery | null;
    precision: number;
    gl: WebGL2RenderingContext | null;
    ext: any;
    query: WebGLQuery | null;
    disjoint: any;
    ns: any;
    threeRendererPatched: boolean;
    gpuQueries: {
        query: WebGLQuery;
    }[];
    renderCount: number;
    constructor({ logsPerSecond, samplesLog, samplesGraph, precision, minimal, horizontal, mode }?: {
        logsPerSecond?: number | undefined;
        samplesLog?: number | undefined;
        samplesGraph?: number | undefined;
        precision?: number | undefined;
        minimal?: boolean | undefined;
        horizontal?: boolean | undefined;
        mode?: number | undefined;
    });
    patchThreeRenderer(renderer: THREE.WebGLRenderer): void;
    resizePanel(panel: Panel, offset: number): void;
    addPanel(panel: Panel, offset: number): Panel;
    showPanel(id: number): void;
    init(canvasOrGL: HTMLCanvasElement | OffscreenCanvas | THREE.WebGLRenderer | WebGL2RenderingContext): void;
    begin(): void;
    end(): void;
    processGpuQueries(): void;
    update(): void;
    endInternal(): number;
    addToAverage(value: number, averageArray: {
        logs: any;
        graph: any;
    }): void;
    beginProfiling(marker: string): void;
    endProfiling(startMarker: string | PerformanceMeasureOptions | undefined, endMarker: string | undefined, measureName: string): void;
    updatePanel(panel: {
        update: any;
    } | null, averageArray: {
        logs: number[];
        graph: number[];
    }): void;
    get domElement(): HTMLDivElement;
    get container(): HTMLDivElement;
}

export { AverageArray, Stats as default };
